#importing the Entity_Recognizer class from the EntityRecognizer.py file 
import sys
import os
import pytest

from VetstoriaNER import EntityRecognizer

TEST_VALUES = [
    pytest.param('i have a cat',['cat']),
    pytest.param('we have a dog',['dog']),
    pytest.param('my name is abdul',None),
    pytest.param('k9',None),
    pytest.param('i am abdul and i currently work as an intern at vetstoria and my pet is a wonderful cat',['cat']),
    pytest.param('i have a cat and a dog',['cat', 'dog']),
    pytest.param('tiger',['tiger']),
    pytest.param('my pet is a fish',['fish']),
    pytest.param('',None),
    pytest.param('i have you',None),
    pytest.param('i have no idea',None)
]


@pytest.mark.parametrize("input,expected",TEST_VALUES)
def test_output(input,expected):
    entity_recognizer = EntityRecognizer('species-detection')
    identified_species_names = entity_recognizer.recognizeSpecies(input)
    assert identified_species_names == expected


import spacy
import os
import sys
from os import environ

class EntityRecognizer():
    def __init__(self,model_name=""):
        self.model_name = None
        if model_name:
            self.model_name = model_name 
        else:
            env_var = environ.get('MODEL_PATH')
            if env_var:
                self.model_name = env_var

        if self.model_name == None or self.model_name == "":
            raise Exception("Spacy model not found. Please pass model path Or define MODEL_PATH enviroment variable") 
            sys.exit(1)    
        else:
            try:
                self.nlp = spacy.load(self.model_name)
            except Exception as e:
                print(e,'\n>>> please pass the correct path to the model or the actual shortlinked name of the model')
                sys.exit(1)

    def recognizeSpecies(self,input_text):
        recognized_species_list = []
        doc = self.nlp(input_text)
        for ent in doc.ents:
            recognized_species_list.append(ent.text)

        if len(recognized_species_list)==0:
            return None
        else:    
            return recognized_species_list 



from setuptools import setup,find_namespace_packages,find_packages
import os
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(name='VetstoriaNER',
install_requires=['spacy'],
setup_requires=['pytest-runner'],
tests_require=['pytest'],
python_requires='>=3.6.9',
version='0.7',
description='Species detection package for Vetstoria',
long_description=long_description,
long_description_content_type='text/markdown',
classifiers=['Intended Audience :: Developers',
            'License :: OSI Approved :: MIT License',
            'Natural Language :: English',
            'Operating System :: OS Independent',
            'Programming Language :: Python'],            
author='Vetstoria',
author_email='riza@vetstoria.com',
packages=find_packages(include=['VetstoriaNER','ner_tests']),
zip_safe=False)